@@ -117,9 +117,6 @@ static sig_atomic_t signaled;
 const char *initddir = "/etc/init.d";
 const char *etcdir = "/etc";
 
-#define LEGACY_DEPENDENCY_PATH "/etc/init.d/."
-#define DEPENDENCY_PATH "/var/lib/insserv/"
-char *dependency_path = DEPENDENCY_PATH;
 #ifndef PATH_MAX
 #define PATH_MAX 2048
 #endif
@@ -861,8 +858,10 @@ void usage(int status)
   fprintf(stderr, "       startpar -v\n");
   fprintf(stderr, "           show version number\n");
   fprintf(stderr, "general options:\n");
+  /*
   fprintf(stderr, "       -l use legacy /etc/init.d path for Makefile-style scripts\n");
-  fprintf(stderr, "          The default is to use the location /var/lib/insserv\n");
+  fprintf(stderr, "          The default is to use the location /lib/insserv\n");
+  */
   fprintf(stderr, "       -p parallel tasks\n");
   fprintf(stderr, "       -t I/O timeout\n");
   fprintf(stderr, "       -T global I/O timeout\n");
@@ -889,7 +888,6 @@ int main(int argc, char **argv)
   char *splashopt = 0;
   sigset_t nmask, omask, smask;
   int status;     /* check if parsing makefile worked */
-  int using_legacy_path = FALSE;      /* use new makefile path by default */
 
   detect_consoles();
 
@@ -902,7 +900,7 @@ int main(int argc, char **argv)
   numcpu = sysconf(_SC_NPROCESSORS_ONLN);
   myname = argv[0];
 
-  while ((c = getopt(argc, argv, "flhp:t:T:a:M:P:R:S:vi:e:d:")) != EOF)
+  while ((c = getopt(argc, argv, "fhp:t:T:a:M:P:R:S:vi:e:d:")) != EOF)
     {
       switch(c)
         {
@@ -927,10 +925,6 @@ int main(int argc, char **argv)
         case 'e':
           etcdir = optarg;
           break;
-        case 'l':
-          dependency_path = LEGACY_DEPENDENCY_PATH;
-          using_legacy_path = TRUE;
-          break;
 	case 'M':
 	  run_mode = optarg;
 	  break;
@@ -1002,21 +996,14 @@ int main(int argc, char **argv)
 	  fprintf(stderr, "invalid run mode %s\n", run_mode);
 	  exit(1);
 	}
-      snprintf(makefile, PATH_MAX, "%sdepend.%s", dependency_path, run_mode);
+      snprintf(makefile, PATH_MAX, "%s/.depend.%s", initddir, run_mode);
       status = parse_makefile(makefile);
-      /* If the parse fails it is probably because the file does not
-         exist. Try alternative location. -- Jesse */
-      if ( (! status) && (! using_legacy_path) )
+      if (! status) 
       {
-         snprintf(makefile, PATH_MAX, "%sdepend.%s", LEGACY_DEPENDENCY_PATH, run_mode);
-         fprintf(stderr, "Trying to find makefile-style script at legacy location: %s\n",
-                         LEGACY_DEPENDENCY_PATH);
-         status = parse_makefile(makefile);
-         if (! status)
-            exit(1);
-      }
-      else if ( (! status) && (using_legacy_path) )
+         fprintf(stderr, "Unable to run scripts using dependency information in %s\n",
+                 initddir);
          exit(1);      /* no other place to try so drop out */
+      }
 
       check_run_files(run_mode, prev_level, run_level);
 
